Resources
=========

* `QPDF Manual`_

* `PDF 1.7`_ ISO Specification PDF 32000-1:2008

* `Adobe extensions`_ to the PDF specification

.. _QPDF Manual: http://qpdf.sourceforge.net/files/qpdf-manual.html

.. _PDF 1.7: https://www.adobe.com/content/dam/acom/en/devnet/pdf/pdfs/PDF32000_2008.pdf

.. _Adobe extensions: https://www.adobe.com/devnet/pdf/pdf_reference.html
